@@ -12,7 +12,7 @@ class CloudBilling(Base):
 
     def __init__(self, credentials, api_key=None):
         """Initialize a class instance."""
-        self.billing = build('cloudbilling', 'v1', credentials=credentials)
+        self.billing = build('cloudbilling', 'v1', credentials=credentials, cache_discovery=False)
 
         # developerKey is needed by services() and skus()
         self.api_key = api_key
@@ -109,14 +109,14 @@ class CloudBilling(Base):
 
     def get_services(self):
         """Return list of servicest."""
-        billing = build('cloudbilling', 'v1', developerKey=self.api_key)
+        billing = build('cloudbilling', 'v1', developerKey=self.api_key, cache_discovery=False)
         services = billing.services()
         request = services.list()
         return self.get_list_items(services, request, 'services')
 
     def get_skus(self, parent):
         """Return list of skus."""
-        billing = build('cloudbilling', 'v1', developerKey=self.api_key)
+        billing = build('cloudbilling', 'v1', developerKey=self.api_key, cache_discovery=False)
         if not re.match('services/', parent):
             parent = 'services/%s' % (parent)
         params = {
