@@ -13,7 +13,6 @@ class CloudAssetInventory(Base):
     def __init__(self, credentials):
         """Initialize a class instance."""
         self.asset = build('cloudasset', 'v1', credentials=credentials, cache_discovery=False)
-
         self.asset_v1 = asset_v1
         self.credentials = credentials
         self.requests = AuthorizedSession(self.credentials)
@@ -50,8 +49,6 @@ class CloudAssetInventory(Base):
             },
             'readTime': read_time,
         }
-        import json
-        print(json.dumps(body, indent=2, sort_keys=True))
         return self.export_assets(parent, body)
 
     def export_assets_to_gcs(
@@ -81,39 +78,45 @@ class CloudAssetInventory(Base):
         operations = self.asset.operations()
         return operations.get(name=name).execute()
 
-    def list_assets(
+    def search_all_iam_policies(
         self,
-        parent,
-        asset_types=None,
-        content_type=None,
-        snapshot_time=None,
-        page_size=1000,
+        scope,
+        asset_types=[],
+        query=None,
+        page_size=1000
     ):
-        """List assets."""
-        body = {
-            'assetTypes': asset_types,
-            'contentType': content_type,
-            'snapshot_time': snapshot_time
+        """Search all iam policies in asset inventory for a given scope."""
+        assets = self.asset.v1()
+        request = assets.searchAllIamPolicies(
+            scope=scope,
+            pageSize=page_size,
+            query=query,
+        )
+        items = []
+        while request is not None:
+            response = request.execute()
+            items += response.get("results", [])
+            request = assets.searchAllIamPolicies_next(request, response)
+        return items
 
-        }
-        # assets = self.asset_v1p5alpha1.projects().assets()
-        # request = assets.list(**params)
-        # return self.get_list_items(assets, request, 'assets')
-        base_url = 'https://cloudasset.googleapis.com/v1p5alpha1'
-        url = '{}/{}/assets'.format(base_url, parent)
-        print('URL: {}'.format(url))
-        response = self.requests.post(url, data=body)
-        response.raise_for_status()
-        print(response.text)
-
-        # client = asset_v1p5alpha1.AssetServiceClient()
-        # response = client.list_assets(
-        #     parent=parent,
-        #     read_time=read_time,
-        #     asset_types=asset_types,
-        #     content_type=content_type,
-        #     page_size=page_size,
-        # )
-        # for page in response.pages:
-        #     for asset in page:
-        #         print(asset)
+    def search_all_resources(
+        self,
+        scope,
+        asset_types=[],
+        query=None,
+        page_size=1000
+    ):
+        """Search all resources in asset inventory for a given scope."""
+        assets = self.asset.v1()
+        request = assets.searchAllResources(
+            scope=scope,
+            assetTypes=asset_types,
+            pageSize=page_size,
+            query=query,
+        )
+        items = []
+        while request is not None:
+            response = request.execute()
+            items += response.get("results", [])
+            request = assets.searchAllResources_next(request, response)
+        return items
