@@ -11,7 +11,7 @@ class CloudDNS(Base):
 
     def __init__(self, credentials=None, project=None):
         """Initialize a class instance."""
-        self.dns = build('dns', 'v1', credentials=credentials)
+        self.dns = build('dns', 'v1', credentials=credentials, cache_discovery=False)
         self.client = client.Client(project)
 
     def get_managed_zones(self, project):
