@@ -10,7 +10,7 @@ class IAM(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.iam = build('iam', 'v1', credentials=credentials)
+        self.iam = build('iam', 'v1', credentials=credentials, cache_discovery=False)
 
     def get_service_accounts(self, project):
         """Return list of project service accounts."""
